@@ -5,6 +5,8 @@ __all__ = ['register', 'enable', 'disable', 'get', 'put', 'exists', 'cached', 'C
 
 from functools import wraps
 
+from lltk.helpers import debug
+
 caches = {}
 
 def register(cache):
@@ -65,9 +67,13 @@ def cached(key = None, extradata = {}):
 				arguments = list(args) + [(a, kwargs[a]) for a in sorted(kwargs.keys())]
 				uid = md5(str(arguments)).hexdigest()
 			if exists(uid):
+				debug('Item \'%s\' is cached (%s).' % (uid, cache))
 				return get(uid)
 			else:
+				debug('Item \'%s\' is not cached (%s).' % (uid, cache))
 				result = f(*args, **kwargs)
+				debug('Caching result \'%s\' as \'%s\' (%s)...' % (result, uid, cache))
+				debug('Extra data: ' + (str(extradata) or 'None'))
 				put(uid, result, extradata)
 				return result
 		return wrapper
